@@ -11,7 +11,7 @@ from git import Repo,GitCommandError
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 log=logging.getLogger(__name__)
-log.setLevel(logging.INFO)
+log.setLevel(logging.WARNING)
 formatter = logging.Formatter(
     fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
     datefmt="%Y-%m-%d %H:%M:%S"
@@ -88,7 +88,7 @@ class Server():
         """使用Python内置方法创建目录（含父目录）"""
         try:
             # 使用exist_ok=True避免重复创建错误
-            shutil.os.makedirs(path, exist_ok=True)
+            os.makedirs(path, exist_ok=True)
         except PermissionError:
             raise RuntimeError(f"权限不足，无法创建目录: {path}")
         except OSError as e:
@@ -135,10 +135,10 @@ class Server():
             if os.path.exists(dest_path):
                 git_dir = os.path.join(dest_path, '.git')
                 if os.path.isdir(git_dir):
-                    log.warning(f"目标路径 '{dest_path}' 已存在且为Git仓库，无法克隆")
+                    log.warning(f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},目标路径 '{dest_path}' 已存在且为Git仓库，无法克隆")
                     return False
                 else:
-                    log.warning(f"目标路径 '{dest_path}' 已存在但不是Git仓库，无法克隆")
+                    log.warning(f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},目标路径 '{dest_path}' 已存在但不是Git仓库，无法克隆")
                     return False
 
             parent_dir = os.path.dirname(dest_path)
@@ -152,13 +152,13 @@ class Server():
             )
 
             if repo.bare:
-                log.warning(f"克隆失败，创建了裸仓库: {dest_path}")
+                log.warning(f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},克隆失败，创建了裸仓库: {dest_path}")
                 return False
 
             current_branch = repo.active_branch.name
             if current_branch != branch:
                 log.warning(
-                    f"克隆成功但分支不匹配 - "
+                    f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},克隆成功，但分支不匹配",
                     f"实际分支: {current_branch}, 预期分支: {branch}"
                 )
                 return False
@@ -166,10 +166,10 @@ class Server():
             return True
 
         except GitCommandError as e:
-            log.warning(f"Git命令执行失败: {str(e)}")
+            log.warning(f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},Git命令执行失败: {str(e)}")
             return False
         except Exception as e:
-            log.warning(f"克隆过程中发生未知错误: {str(e)}")
+            log.warning(f"克隆仓库: {repo_url} branch {branch} 到 {dest_path},克隆过程中发生未知错误: {str(e)}")
             return False
 
     def find_all_file(
@@ -189,7 +189,7 @@ class Server():
 
         root_dir = os.path.abspath(root_dir)
         if not os.path.isdir(root_dir):
-            log.warning(f"根目录不存在或不是目录: {root_dir}")
+            log.warning(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},根目录不存在或不是目录: {root_dir}")
             return None
 
         if suffix is not None and not suffix.startswith('.'):
@@ -202,10 +202,10 @@ class Server():
             dirnames[:] = [d for d in dirnames if d not in exclude_dirs_set]
             for filename in filenames:
                 if filename in exclude_files_set:
-                    log.warning(f"文件被排除: {filename}")
+                    log.warning(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件被排除: {filename}")
                     continue
                 if suffix is not None and not filename.endswith(suffix):
-                    log.warning(f"文件后缀不匹配: {filename}")
+                    log.warning(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件后缀不匹配: {filename}")
                     continue
                 processed_name = filename if with_suffix else os.path.splitext(filename)[0]
                 if only_file_name:
@@ -241,10 +241,10 @@ class Server():
     def read_json(self, file_path: str) -> Optional[Any]:
         log.info(f"正在读取JSON文件 - {file_path}")
         if not os.path.exists(file_path):
-            log.warning(f"错误: 文件不存在 - {file_path}")
+            log.warning(f"读取JSON文件 - {file_path},错误: 文件不存在 - {file_path}")
             return None
         if not os.path.isfile(file_path):
-            log.warning(f"错误: 不是有效的文件 - {file_path}")
+            log.warning(f"读取JSON文件 - {file_path},错误: 不是有效的文件 - {file_path}")
             return None
         try:
             with open(file_path, 'r', encoding='utf-8') as file:
@@ -253,22 +253,22 @@ class Server():
                     log.info(f"成功读取JSON文件 - {file_path}, data is {json_data}")
                     return json_data
                 except json.JSONDecodeError as e:
-                    log.warning("错误: JSON解析失败 - {str(e)}，文件: {file_path}")
+                    log.warning("读取JSON文件 - {file_path},错误: JSON解析失败 - {str(e)}，文件: {file_path}")
                     return None
                 except Exception as e:
-                    log.warning(f"错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
+                    log.warning(f"读取JSON文件 - {file_path},错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
                     return None
         except PermissionError:
-            log.warning(f"错误: 没有权限打开文件 - {file_path}")
+            log.warning(f"读取JSON文件 - {file_path},错误: 没有权限打开文件 - {file_path}")
             return None
         except Exception as e:
-            log.warning(f"错误: 打开文件时发生意外 - {str(e)}，文件: {file_path}")
+            log.warning(f"读取JSON文件 - {file_path},错误: 打开文件时发生意外 - {str(e)}，文件: {file_path}")
             return None
 
     def get_abs_path(self, file_name: str, dest_dir: str) -> Optional[str]:
         log.info(f"正在获取绝对路径 - 文件名: {file_name}，目标目录: {dest_dir}")
         if not os.path.isdir(dest_dir):
-            log.warning(f"错误: 目标目录不存在或不是目录 - {dest_dir}")
+            log.warning(f"获取绝对路径 - 文件名: {file_name}，目标目录: {dest_dir} 错误: 目标目录不存在或不是目录 - {dest_dir}")
             return None
 
         for root, _, files in os.walk(dest_dir):
@@ -277,5 +277,5 @@ class Server():
                 log.info(f"成功获取绝对路径 - 文件名: {file_name}，绝对路径: {abs_path}")
                 return abs_path
 
-        log.warning(f"未找到文件 - {file_name}，目录: {dest_dir}")
+        log.warning(f"获取绝对路径 - 文件名: {file_name}，目标目录: {dest_dir},未找到文件 - {file_name}，目录: {dest_dir}")
         return None
\ No newline at end of file
